==> libsambox-java_1.1.46.orig.tar.xz: sambox-1.1.46/src/main/java/org/sejda/sambox/util/Version.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.sejda.sambox.util;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.sejda.sambox.SAMBox;

/**
 * Exposes PDFBox version.
 */
public final class Version
{

    private Version()
    {
        // static helper
    }

    /**
     * @return the version of PDFBox.
     */
    public static String getVersion()
    {
        try (InputStream stream = Version.class.getClassLoader().getResourceAsStream(
                SAMBox.SAMBOX_PROPERTIES))
        {
            if (stream != null)
            {
                Properties properties = new Properties();
                properties.load(stream);
                return properties.getProperty("sambox.version", "");
            }
        }
        catch (IOException io)
        {
            // nothing
        }
        return null;
    }
}

==> libsambox-java_2.3.4.orig.tar.xz: sambox-2.3.4/src/main/java/org/sejda/sambox/util/Version.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.sejda.sambox.util;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.sejda.sambox.SAMBox;

/**
 * Exposes SAMBox version.
 */
public final class Version
{

    private Version()
    {
        // static helper
    }

    /**
     * @return the version of SAMBox.
     */
    public static String getVersion()
    {
        try (InputStream stream = Version.class.getResourceAsStream(SAMBox.SAMBOX_PROPERTIES))
        {
            if (stream != null)
            {
                Properties properties = new Properties();
                properties.load(stream);
                return properties.getProperty("sambox.version", "");
            }
        }
        catch (IOException io)
        {
            // nothing
        }
        return "";
    }
}
